@@ -48,7 +48,7 @@ class Client(pystac.Catalog):
             catalog : A :class:`Client` instance for this Catalog/API
         """
         cat = cls.from_file(url, headers=headers, parameters=parameters)
-        search_link = cat.get_links('search', media_type=pystac.MediaType.GEOJSON)
+        search_link = cat.get_search_link()
         # if there is a search link, but no conformsTo advertised, ignore conformance entirely
         # NOTE: this behavior to be deprecated as implementations become conformant
         if ignore_conformance or ('conformsTo' not in cat.extra_fields.keys()
@@ -142,7 +142,7 @@ class Client(pystac.Catalog):
         else:
             yield from super().get_items()
 
-    def search(self, **kwargs: Any) -> ItemSearch:
+    def search(self, require_geojson_link: bool = False, **kwargs: Any) -> ItemSearch:
         """Query the ``/search`` endpoint using the given parameters.
 
         This method returns an :class:`~pystac_client.ItemSearch` instance, see that class's documentation
@@ -168,9 +168,22 @@ class Client(pystac.Catalog):
                 <https://github.com/radiantearth/stac-api-spec/tree/master/item-search>`__ or does not have a link with
                 a ``"rel"`` type of ``"search"``.
         """
-        search_link = self.get_single_link('search', media_type=pystac.MediaType.GEOJSON)
+        search_link = self.get_search_link()
         if search_link is None:
             raise NotImplementedError(
                 'No link with "rel" type of "search" could be found in this catalog')
 
         return ItemSearch(search_link.target, stac_io=self._stac_io, client=self, **kwargs)
+
+    def get_search_link(self) -> Optional[pystac.Link]:
+        """Returns this client's search link.
+
+        Searches for a link with rel="search" and either a GEOJSON or JSON media type.
+
+        Returns:
+            Optional[pystac.Link]: The search link, or None if there is not one found.
+        """
+        return next((link for link in self.links
+                     if link.rel == "search" and (link.media_type == pystac.MediaType.GEOJSON
+                                                  or link.media_type == pystac.MediaType.JSON)),
+                    None)
